@@ -7,18 +7,30 @@ import time
 import re
 
 class EV3Searcher:
-    def __init__(self) -> None:
+    def __init__(self, status_messages=True) -> None:
+        self.__status_messages = status_messages
         pass
 
     def search_all(self, duration=10):
+        if self.__status_messages:
+            print("{}: Searching for all Bluetooth Devices in your Area".format(time.asctime()), file=sys.stderr)
         devices = bluetooth.discover_devices(duration=duration, lookup_names=True)
+        if self.__status_messages:
+            for x, y in devices:
+                print("-----------------")
+                print(f"Device Name: {y}")
+                print(f"Mac Address: {x}")
         return devices
 
     def search_by_name(self, name):
+        if self.__status_messages:
+            print("{}: Searching for an EV3 Called {}".format(time.asctime(), name), file=sys.stderr)
         devices = bluetooth.discover_devices(lookup_names=True)
         for x, y in devices:
             if y == name:
+                print("{}: Found your EV3 with the address {}".format(time.asctime(), x), file=sys.stderr)
                 return x
+        print("{}: Couldn't find your EV3 {}".format(time.asctime(), name), file=sys.stderr)
         return None
 
 class Message:
@@ -37,7 +49,7 @@ class EV3:
         """
         if not re.match("[0-9a-f]{2}([-:]?)[0-9a-f]{2}(\\1[0-9a-f]{2}){4}$", address.lower()):
             name = address
-            address = EV3Searcher().search_by_name(address)
+            address = EV3Searcher(status_messages=status_messages).search_by_name(address)
             if address == None:
                 raise Exception("No EV3 with name {} found".format(name))
         if status_messages:
@@ -52,7 +64,7 @@ class EV3:
         except Exception as e:
             if status_messages:
                 print("{}: BT failed to connect - {}".format(time.asctime(),e), file=sys.stderr)
-            raise Exception("Failed to connect to EV3g") from None
+            raise Exception("Failed to connect to EV3") from None
 
         self.__received_messages = []
         self.__status_messages = status_messages
